# Fink anomaly detection model
The module is designed to train a model to detect anomalies in photometric data.

**positional arguments:**

  * _dataset_dir_      : Input dir for dataset

**optional arguments:**

  * _-h_, --help       : show this help message and exit
  
  * _--n_jobs N_JOBS_  : Number of threads (default: -1)
